@@ -11,13 +11,16 @@ from tfx.types import artifact_utils
 from tfx.proto import example_gen_pb2
 from tfx.components.example_gen import utils
 from tfx.types import channel_utils
-from salure_tfx_extensions.components.sklearn_trainer import executor
+from salure_tfx_extensions.components.sklearn_transform import executor
 from salure_tfx_extensions.types.component_specs import SKLearnTransformSpec
 
 
 class SKLearnTransform(base_component.BaseComponent):
     """A component for preprocessing examples using SKLearn"""
 
+    SPEC_CLASS = SKLearnTransformSpec
+    EXECUTOR_SPEC = executor_spec.ExecutorClassSpec(executor.Executor)
+
     # TODO
     def __init__(self,
                  examples: types.Channel,
@@ -26,15 +29,20 @@ class SKLearnTransform(base_component.BaseComponent):
                  instance_name: Optional[Text] = None,
                  enable_cache: Optional[bool] = None):
 
-        output = types.Channel(
+        transform_pipeline = types.Channel(
             type=stfxe_artifacts.SKLearnPrepocessor, artifacts=[stfxe_artifacts.SKLearnPrepocessor()]
         )
 
+        transformed_examples = types.Channel(
+            type=standard_artifacts.Examples, artifacts=[standard_artifacts.Examples()]
+        )
+
         spec = SKLearnTransformSpec(
             examples=examples,
             module_file=module_file,
             pipeline_name=pipeline_name,
-            transformed_examples=output,
+            transform_pipeline=transform_pipeline,
+            transformed_examples=transformed_examples,
         )
 
         super(SKLearnTransform, self).__init__(
